
# Slot: systematic synonym


more commonly used for gene symbols in yeast

URI: [biolink:systematic_synonym](https://w3id.org/biolink/vocab/systematic_synonym)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [LabelType](types/LabelType.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | GOP:systematic_synonym |

